package SliMP3::Wav;

# SliMP3 Server Copyright (C) 2001 Sean Adams, Slim Devices Inc.
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License, 
# version 2.

###############################################################################
# FILE: SliMP3::Wav.pm
#
# DESCRIPTION:
#   Extract Wav tag information and store in a hash for easy retrieval.
#   Useage of Nick Peskett's Audio::Wav
#
# NOTES:
#   This code has only been tested on Linux.
###############################################################################
use strict;

use Audio::Wav;

# Global vars
use vars qw(
	@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION $REVISION $AUTOLOAD
);

@ISA = 'Exporter';
@EXPORT = qw(
	get_wavtag
);

# Things that can be exported explicitly
@EXPORT_OK = qw(get_wavtag);

%EXPORT_TAGS = (
	all	=> [@EXPORT, @EXPORT_OK]
);

# Given a file, return a hash of name value pairs,
# where each name is a tag name.
sub get_wavtag
{
	# Get the pathname to the file
	my $file = shift || "";

	# This hash will map the keys in the tag to their values.
	my $tag = {};

	# Make sure the file exists.
#	return undef unless -s $file;

	my $wav = new Audio::Wav;
	my $read = $wav->read( $file);
	my $nSeconds = $read->length_seconds();
	my $nLength = SliMP3::Prefs::get("wavmp3samplerate") * 1000 / 8 * $nSeconds;	# kbit per second to bytes per second

	$tag->{'SIZE'} = $nLength;
	$tag->{'SECS'} = $nSeconds;

	return $tag;
}

1;
